# LinkageLinkageType


## Enum

* `START` (value: `'Start'`)

* `SUCCESS` (value: `'Success'`)

* `FAILURE` (value: `'Failure'`)

* `ITERATE` (value: `'Iterate'`)

* `TRUE` (value: `'True'`)

* `FALSE` (value: `'False'`)

* `APPROVE` (value: `'Approve'`)

* `REJECT` (value: `'Reject'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


